<?php
// Shortcode és AJAX kezelő

// Biztonsági ellenőrzés
if (!defined('ABSPATH')) {
    exit; // Közvetlen hozzáférés megakadályozása
}

// Shortcode a feliratkozási űrlap megjelenítéséhez
function hirlevel_feliratkozas_shortcode() {
    ob_start();
    include plugin_dir_path(dirname(__FILE__)) . 'templates/form-template.php';
    return ob_get_clean();
}
add_shortcode('hirlevel_feliratkozas', 'hirlevel_feliratkozas_shortcode');

// AJAX handler a feliratkozáshoz
function hirlevel_process_subscription() {
    // Ellenőrizzük a nonce-t biztonsági okokból
    check_ajax_referer('hirlevel_feliratkozas_nonce', 'nonce');
    
    $email = sanitize_email($_POST['email']);
    $accepted_terms = isset($_POST['accepted_terms']) ? true : false;
    
    if (empty($email)) {
        wp_send_json_error(array('message' => 'Az email cím megadása kötelező!'));
        return;
    }
    
    if (!$accepted_terms) {
        wp_send_json_error(array('message' => 'Kérjük, fogadd el az adatkezelési tájékoztatót!'));
        return;
    }
    
    // API kulcs, username és domain a WordPress beállításokból
    $api_key = get_option('hirlevel_feliratkozas_api_key', '');
    $domain = get_option('hirlevel_feliratkozas_api_domain', site_url());
    $username = get_option('hirlevel_feliratkozas_username', '');
    
    if (empty($api_key)) {
        wp_send_json_error(array('message' => 'Az API kulcs nincs beállítva! Kérjük, állítsd be az admin felületen.'));
        return;
    }
    
    if (empty($username)) {
        wp_send_json_error(array('message' => 'A felhasználónév nincs beállítva! Kérjük, állítsd be az admin felületen.'));
        return;
    }
    
    // API kérés küldése a fix végpontnak
    $response = wp_remote_post(HIRLEVEL_API_ENDPOINT, array(
        'headers' => array(
            'Authorization' => 'Bearer ' . $api_key,
            'Origin' => $domain,
            'Content-Type' => 'application/json'
        ),
        'body' => json_encode(array(
            'email' => $email,
            'username' => $username
        ))
    ));
    
    // Válasz ellenőrzése
    if (is_wp_error($response)) {
        wp_send_json_error(array('message' => 'Hiba történt a kapcsolódás során: ' . $response->get_error_message()));
        return;
    }
    
    $body = json_decode(wp_remote_retrieve_body($response), true);
    $status_code = wp_remote_retrieve_response_code($response);
    
    if ($status_code === 201 || $status_code === 200) {
        // Sikeres feliratkozás
        $success_message = get_option('hirlevel_feliratkozas_success_message', 'Sikeresen feliratkoztál!');
        wp_send_json_success(array('message' => $success_message));
    } else {
        // Hiba kezelése - Kinyerjük az API válaszából a hibaüzenetet
        $error_message = isset($body['error']) ? $body['error'] : 'Ismeretlen hiba történt.';
        
        // Ha a hibaüzenet JSON formátumban van, kicsomagoljuk
        if (is_string($error_message) && strpos($error_message, '{') === 0) {
            try {
                $parsed_error = json_decode($error_message, true);
                if (isset($parsed_error['error'])) {
                    $error_message = $parsed_error['error'];
                }
            } catch (Exception $e) {
                // Ha nem sikerült parse-olni, megtartjuk az eredeti üzenetet
            }
        }
        
        wp_send_json_error(array('message' => $error_message));
    }
}
add_action('wp_ajax_hirlevel_feliratkozas', 'hirlevel_process_subscription');
add_action('wp_ajax_nopriv_hirlevel_feliratkozas', 'hirlevel_process_subscription');

// AJAX handler a szövegek lekéréséhez a JavaScript számára
function hirlevel_get_texts() {
    // Ellenőrizzük a nonce-t biztonsági okokból
    check_ajax_referer('hirlevel_feliratkozas_nonce', 'nonce');
    
    // Szövegek beolvasása az opcióktól
    $form_title = get_option('hirlevel_feliratkozas_form_title', 'Iratkozz fel hírlevelünkre');
    $form_subtitle = get_option('hirlevel_feliratkozas_form_subtitle', 'Értesülj az új cikkekről és exkluzív tartalmakról');
    $email_label = get_option('hirlevel_feliratkozas_email_label', 'Email cím');
    $terms_text = get_option('hirlevel_feliratkozas_terms_text', 'Elfogadom az adatkezelési tájékoztatót, és hozzájárulok a személyes adataim kezeléséhez.');
    $privacy_link = get_option('hirlevel_feliratkozas_privacy_link', site_url('/adatkezeles'));
    $button_text = get_option('hirlevel_feliratkozas_button_text', 'Feliratkozás');
    $privacy_note = get_option('hirlevel_feliratkozas_privacy_note', 'Tiszteletben tartjuk a magánéletedet. Bármikor leiratkozhatsz.');
    
    // Adatkezelési tájékoztató szöveg és link elkészítése
    $terms_text_with_link = str_replace('adatkezelési tájékoztatót', '<a href="' . esc_url($privacy_link) . '" target="_blank">adatkezelési tájékoztatót</a>', $terms_text);
    
    $response = array(
        'title' => $form_title,
        'subtitle' => $form_subtitle,
        'email_label' => $email_label,
        'terms_text' => $terms_text,
        'terms_text_with_link' => $terms_text_with_link,
        'button_text' => $button_text,
        'privacy_note' => $privacy_note,
        'success_message' => get_option('hirlevel_feliratkozas_success_message', 'Sikeresen feliratkoztál!')
    );
    
    wp_send_json_success($response);
}
add_action('wp_ajax_hirlevel_get_texts', 'hirlevel_get_texts');
add_action('wp_ajax_nopriv_hirlevel_get_texts', 'hirlevel_get_texts');